==> 0.11.3.tar.gz: lib/src/router/bitbucket/bitbucket_impl.dart <==
library ac_dart.addon_routebuilder.bibucket.impl;

import 'package:atlassian_connect_shelf/router.dart' hide router;

import 'package:logging/logging.dart';
import 'package:atlassian_connect_shelf/src/router/common/standard_routes_impl.dart';
import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/bitbucket.dart';
import 'package:atlassian_connect_shelf/src/router/bitbucket/bitbucket.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/bitbucket_impl.dart';
import 'package:shelf_oauth/shelf_oauth.dart';
import 'package:shelf_auth/shelf_auth.dart';
import 'package:mojito/mojito.dart' hide Router, router;

final Logger _log = new Logger('ac_dart.addon_routebuilder.bibucket');

class BitbucketRouterBuilderImpl extends StandardAddonRouterBuilderImpl<
    BitbucketModuleList,
    BitbucketScope,
    BitbucketConnectAddon,
    BitbucketDescriptorBuilder> implements BitbucketRouterBuilder {
  BitbucketRouterBuilderImpl(
      Router router,
      path,
      String addonKey,
      Uri baseUrl,
      AcHostRegistrationRepository hostRegistrationRepository,
      ClientIdFactory oauthClientIdFactory,
      IsDevMode isDevMode,
      {SessionHandler sessionHandler,
      String addonSecret})
      : super(
            router,
            path,
            new BitbucketDescriptorBuilderImpl(addonKey, baseUrl),
            addonKey,
            baseUrl,
            hostRegistrationRepository,
            isDevMode,
            oauthClientIdFactory: oauthClientIdFactory,
            sessionHandler: sessionHandler,
            addonSecret: addonSecret);

  void addSpaRepoPage(path, String key, String name, BitbucketLocation location,
      {String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    addSpaPage(BitbucketModuleTypes.repoPage, path, key, name, location,
        spaBasePath: spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragment: additionalUriFragment);
  }
}

==> 0.11.6.tar.gz: lib/src/router/bitbucket/bitbucket_impl.dart <==
library ac_dart.addon_routebuilder.bitbucket.impl;

import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:atlassian_connect_shelf/router.dart' hide router;
import 'package:atlassian_connect_shelf/src/descriptor_builders/bitbucket.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/bitbucket_impl.dart';
import 'package:atlassian_connect_shelf/src/router/bitbucket/bitbucket.dart';
import 'package:atlassian_connect_shelf/src/router/common/standard_routes_impl.dart';
import 'package:logging/logging.dart';
import 'package:mojito/mojito.dart' hide Router, router;
import 'package:shelf_auth/shelf_auth.dart';
import 'package:shelf_oauth/shelf_oauth.dart';

final Logger _log = new Logger('ac_dart.addon_routebuilder.bitbucket');

class BitbucketRouterBuilderImpl extends StandardAddonRouterBuilderImpl<
    BitbucketModuleList,
    BitbucketScope,
    BitbucketConnectAddon,
    BitbucketDescriptorBuilder,
    BitbucketLocation> implements BitbucketRouterBuilder {
  BitbucketRouterBuilderImpl(
      Router router,
      path,
      String addonKey,
      Uri baseUrl,
      AcHostRegistrationRepository hostRegistrationRepository,
      ClientIdFactory oauthClientIdFactory,
      IsDevMode isDevMode,
      {SessionHandler sessionHandler,
      String addonSecret})
      : super(
            router,
            path,
            new BitbucketDescriptorBuilderImpl(addonKey, baseUrl),
            addonKey,
            baseUrl,
            hostRegistrationRepository,
            isDevMode,
            oauthClientIdFactory: oauthClientIdFactory,
            sessionHandler: sessionHandler,
            addonSecret: addonSecret);

  void addSpaRepoPage(path, String key, String name, BitbucketLocation location,
      {String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    addSpaPage(BitbucketModuleTypes.repoPage, path, key, name, location,
        spaBasePath: spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragment: additionalUriFragment);
  }

  @override
  void addRepoPage(path, String key, String name, BitbucketLocation location,
      Function handler) {
    addPage(BitbucketModuleTypes.repoPage, path, key, name, location, handler);
  }
}
